==> isis-fish-3.3.0.5-sources.jar: fr/ifremer/isisfish/entities/Cell.java <==
package fr.ifremer.isisfish.entities;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  txtFields={"name","comment"},
  numFields={"latitude","longitude"},
  boolFields={"land"}
)

public interface Cell extends TopiaEntity {     String NAME = "name";
     String LATITUDE = "latitude";
     String LONGITUDE = "longitude";
     String LAND = "land";
     String COMMENT = "comment";
    /**
     * setName :
     * @param name La valeur de l'attribut name à positionner.
     */

     void setName(String name);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setLatitude :
     * @param latitude La valeur de l'attribut latitude à positionner.
     */

     void setLatitude(float latitude);

    /**
     * getLatitude :
     * @return float 
     */

     float getLatitude();

    /**
     * setLongitude :
     * @param longitude La valeur de l'attribut longitude à positionner.
     */

     void setLongitude(float longitude);

    /**
     * getLongitude :
     * @return float 
     */

     float getLongitude();

    /**
     * setLand :
     * @param land La valeur de l'attribut land à positionner.
     */

     void setLand(boolean land);

    /**
     * getLand :
     * @return boolean 
     */

     boolean getLand();

    /**
     * setComment :
     * @param comment La valeur de l'attribut comment à positionner.
     */

     void setComment(String comment);

    /**
     * getComment :
     * @return String 
     */

     String getComment();

    /**
     * getFisheryRegion :
     * @return FisheryRegion 
     */

     FisheryRegion getFisheryRegion();


} //Cell

==> isis-fish-3.3.0.6-sources.jar: fr/ifremer/isisfish/entities/Cell.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 1999 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */
package fr.ifremer.isisfish.entities;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  txtFields={Cell.NAME, Cell.COMMENT},
  numFields={Cell.LATITUDE, Cell.LONGITUDE},
  boolFields={Cell.LAND}
)

public interface Cell extends TopiaEntity {     String NAME = "name";
     String LATITUDE = "latitude";
     String LONGITUDE = "longitude";
     String LAND = "land";
     String COMMENT = "comment";
    /**
     * setName :
     * @param name La valeur de l'attribut name à positionner.
     */

     void setName(String name);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setLatitude :
     * @param latitude La valeur de l'attribut latitude à positionner.
     */

     void setLatitude(float latitude);

    /**
     * getLatitude :
     * @return float 
     */

     float getLatitude();

    /**
     * setLongitude :
     * @param longitude La valeur de l'attribut longitude à positionner.
     */

     void setLongitude(float longitude);

    /**
     * getLongitude :
     * @return float 
     */

     float getLongitude();

    /**
     * setLand :
     * @param land La valeur de l'attribut land à positionner.
     */

     void setLand(boolean land);

    /**
     * getLand :
     * @return boolean 
     */

     boolean getLand();

    /**
     * setComment :
     * @param comment La valeur de l'attribut comment à positionner.
     */

     void setComment(String comment);

    /**
     * getComment :
     * @return String 
     */

     String getComment();

    /**
     * getFisheryRegion :
     * @return FisheryRegion 
     */

     FisheryRegion getFisheryRegion();


} //Cell
